@@ -1,9 +1,13 @@
+user_pref("app.normandy.api_url", "");
 user_pref("app.normandy.enabled", false);
 user_pref("app.shield.optoutstudies.enabled", false);
 user_pref("app.update.doorhanger", false);
 user_pref("beacon.enabled", false);
-user_pref("browser.aboutwelcome.enabled", false);
 user_pref("browser.aboutConfig.showWarning", false);
+user_pref("browser.aboutwelcome.enabled", false);
+user_pref("browser.crashReports.unsubmittedCheck.autoSubmit2", false);
+user_pref("browser.crashReports.unsubmittedCheck.autoSubmit", false);
+user_pref("browser.crashReports.unsubmittedCheck.enabled", false);
 user_pref("browser.customizemode.tip0.shown", true);
 user_pref("browser.disableResetPrompt", true);
 user_pref("browser.fixup.alternate.enabled", false);
@@ -13,8 +17,16 @@ user_pref("browser.newtabpage.activity-stream.asrouter.disable-captive-portal-vp
 user_pref("browser.newtabpage.activity-stream.asrouter.userprefs.cfr.addons", false);
 user_pref("browser.newtabpage.activity-stream.asrouter.userprefs.cfr.features", false);
 user_pref("browser.newtabpage.activity-stream.feeds.section.highlights", false);
+user_pref("browser.newtabpage.activity-stream.feeds.section.topstories", false);
 user_pref("browser.newtabpage.activity-stream.feeds.snippets", false);
 user_pref("browser.newtabpage.activity-stream.feeds.topsites", false);
+user_pref("browser.newtabpage.activity-stream.section.highlights.includeBookmarks", false);
+user_pref("browser.newtabpage.activity-stream.section.highlights.includeDownloads", false);
+user_pref("browser.newtabpage.activity-stream.section.highlights.includePocket", false);
+user_pref("browser.newtabpage.activity-stream.section.highlights.includeVisited", false);
+user_pref("browser.newtabpage.activity-stream.showSearch", false);
+user_pref("browser.newtabpage.activity-stream.showSponsored", false);
+user_pref("browser.newtabpage.activity-stream.showSponsoredTopSites", false);
 user_pref("browser.newtabpage.enabled", false);
 user_pref("browser.newtabpage.enhanced", false);
 user_pref("browser.newtabpage.introShown", true);
@@ -22,15 +34,22 @@ user_pref("browser.newtab.preload", false);
 user_pref("browser.privatebrowsing.promoEnabled", false);
 user_pref("browser.privatebrowsing.promoTitleEnabled", false);
 user_pref("browser.reader.detectedFirstArticle", true);
-user_pref("browser.search.hiddenOneOffs", "Google,Amazon.com,Bing,DuckDuckGo,Wikipedia (en)");
+user_pref("browser.search.hiddenOneOffs", "Google,Amazon.com,Bing,DuckDuckGo,eBay,Wikipedia (en)");
 user_pref("browser.search.suggest.enabled", false);
 user_pref("browser.selfsupport.url", "");
 user_pref("browser.send_pings", false);
 user_pref("browser.shell.checkDefaultBrowser", false);
 user_pref("browser.startup.blankWindow", true);
+user_pref("browser.startup.couldRestoreSession.count", 2);
 user_pref("browser.startup.homepage", "about:blank");
+user_pref("browser.startup.homepage_override.mstone", "ignore");
+user_pref("browser.tabs.crashReporting.sendReport", false);
 user_pref("browser.toolbarbuttons.introduced.pocket-button", true);
 user_pref("browser.toolbars.bookmarks.2h2020", false);
+user_pref("browser.urlbar.groupLabels.enabled", false);
+user_pref("browser.urlbar.quicksuggest.enabled", false);
+user_pref("browser.urlbar.speculativeConnect.enabled", false);
+user_pref("browser.urlbar.suggest.quicksuggest.nonsponsored", false);
 user_pref("browser.urlbar.suggest.quicksuggest.sponsored", false);
 user_pref("browser.urlbar.trimURLs", false);
 user_pref("datareporting.healthreport.service.enabled", false);
@@ -40,6 +59,7 @@ user_pref("devtools.everOpened", true);
 user_pref("devtools.jsonview.enabled", false);
 user_pref("devtools.netmonitor.persistlog", true);
 user_pref("devtools.webconsole.persistlog", true);
+user_pref("doh-rollout.disable-heuristics", true);
 user_pref("dom.battery.enabled", false);
 user_pref("dom.event.clipboardevents.enabled", false);
 user_pref("experiments.enabled", false);
@@ -51,6 +71,7 @@ user_pref("extensions.privatebrowsing.notification", true);
 user_pref("extensions.recommendations.hideNotice", true);
 user_pref("extensions.screenshots.upload-disabled", true);
 user_pref("extensions.shownSelectionUI", true);
+user_pref("extensions.ui.lastCategory", "addons://list/extension");
 user_pref("general.warnOnAboutConfig", false);
 user_pref("geo.enabled", false);
 user_pref("keyword.enabled", false);
@@ -65,7 +86,9 @@ user_pref("network.captive-portal-service.enabled", false);
 user_pref("network.cookie.cookieBehavior", 1);
 user_pref("network.dns.disablePrefetch", true);
 user_pref("network.http.referer.spoofSource", true);
+user_pref("network.IDN_show_punycode", true);
 user_pref("network.predictor.enabled", false);
+user_pref("network.predictor.enable-prefetch", false);
 user_pref("network.prefetch-next", false);
 user_pref("network.trr.mode", 0);
 user_pref("pdfjs.enablescripting", false);
@@ -81,8 +104,18 @@ user_pref("privacy.trackingprotection.pbmode.enabled", true);
 user_pref("signon.includeOtherSubdomainsInLookup", false);
 user_pref("startup.homepage_welcome_url", "about:blank");
 user_pref("toolkit.legacyUserProfileCustomizations.stylesheets", true);
+user_pref("toolkit.telemetry.archive.enabled", false);
+user_pref("toolkit.telemetry.bhrPing.enabled", false);
 user_pref("toolkit.telemetry.enabled", false);
+user_pref("toolkit.telemetry.firstShutdownPing.enabled", false);
+user_pref("toolkit.telemetry.hybridContent.enabled", false);
+user_pref("toolkit.telemetry.newProfilePing.enabled", false);
 user_pref("toolkit.telemetry.prompted", 2);
 user_pref("toolkit.telemetry.rejected", true);
+user_pref("toolkit.telemetry.reportingpolicy.firstRun", false);
+user_pref("toolkit.telemetry.server", "");
+user_pref("toolkit.telemetry.shutdownPingSender.enabled", false);
+user_pref("toolkit.telemetry.unified", false);
 user_pref("toolkit.telemetry.unifiedIsOptIn", false);
+user_pref("toolkit.telemetry.updatePing.enabled", false);
 user_pref("trailhead.firstrun.didSeeAboutWelcome", true);
